@@ -211,6 +211,10 @@ def is_retryable(status_code):
   return str(status_code) in ['502', '429'] or not status_code
 
 
+def is_unauthorized(status_code):
+  return str(status_code) in ['401', '403']
+
+
 def validate_response(response, error_message, success_message=None):
   if not is_success(response['status_code']):
     response['error_message'] = '%s %s:%s' % (error_message, response['status_code'], response['content'])
